@@ -1,6 +1,5 @@
-#!/usr/bin/env perl
 package NetHack::Item::Spoiler::Food;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use strict;
 use warnings;
@@ -12,107 +11,110 @@ sub _list {
     my $food = {
         'meatball' => {
             price => 5, weight => 1, nutrition => 5, time => 1,
-            plural => 'meatballs', stackable => 1,
+            plural => 'meatballs', stackable => 1, material => 'flesh',
         },
         'meat ring' => {
             price => 5, weight => 1, nutrition => 5, time => 1,
-            plural => 'meat rings',
+            plural => 'meat rings', material => 'flesh',
         },
         'meat stick' => {
             price => 5, weight => 1, nutrition => 5, time => 1,
-            plural => 'meat sticks', stackable => 1,
+            plural => 'meat sticks', stackable => 1, material => 'flesh',
         },
         'tripe ration' => {
             price => 15, weight => 10, nutrition => 200, time => 2, unsafe => 1,
-            plural => 'tripe rations', stackable => 1,
+            plural => 'tripe rations', stackable => 1, material => 'flesh',
         },
         'huge chunk of meat' => {
             price => 105, weight => 400, nutrition => 2000, time => 20,
             plural => 'huge chunks of meat', stackable => 1,
+            material => 'flesh',
         },
         'kelp frond' => {
             price => 6, weight => 1, nutrition => 30, time => 1,
-            plural => 'kelp fronds', stackable => 1,
+            plural => 'kelp fronds', stackable => 1, material => 'veggy',
         },
         'eucalyptus leaf' => {
             price => 6, weight => 1, nutrition => 30, time => 1,
-            plural => 'eucalyptus leaves', stackable => 1,
+            plural => 'eucalyptus leaves', stackable => 1, material => 'veggy',
         },
         'clove of garlic' => {
             price => 7, weight => 1, nutrition => 40, time => 1,
-            plural => 'cloves of garlic', stackable => 1,
+            plural => 'cloves of garlic', stackable => 1, material => 'veggy',
         },
         'sprig of wolfsbane' => {
             price => 7, weight => 1, nutrition => 40, time => 1,
             plural => 'sprigs of wolfsbane', stackable => 1,
+            material => 'veggy',
         },
         'apple' => {
             price => 7, weight => 2, nutrition => 50, time => 1,
-            plural => 'apples', stackable => 1,
+            plural => 'apples', stackable => 1, material => 'veggy',
         },
         'carrot' => {
             price => 7, weight => 2, nutrition => 50, time => 1,
-            plural => 'carrots', stackable => 1,
+            plural => 'carrots', stackable => 1, material => 'veggy',
         },
         'pear' => {
             price => 7, weight => 2, nutrition => 50, time => 1,
-            plural => 'pears', stackable => 1,
+            plural => 'pears', stackable => 1, material => 'veggy',
         },
         'banana' => {
             price => 9, weight => 2, nutrition => 80, time => 1,
-            plural => 'bananas', stackable => 1,
+            plural => 'bananas', stackable => 1, material => 'veggy',
         },
         'orange' => {
             price => 9, weight => 2, nutrition => 80, time => 1,
-            plural => 'oranges', stackable => 1,
+            plural => 'oranges', stackable => 1, material => 'veggy',
         },
         'melon' => {
             price => 10, weight => 5, nutrition => 100, time => 1,
-            plural => 'melons', stackable => 1,
+            plural => 'melons', stackable => 1, material => 'veggy',
         },
         'slime mold' => {
             price => 17, weight => 5, nutrition => 250, time => 1,
-            plural => 'slime molds', stackable => 1,
+            plural => 'slime molds', stackable => 1, material => 'veggy',
         },
         'fortune cookie' => {
             price => 7, weight => 1, nutrition => 40, time => 1,
-            plural => 'fortune cookies', stackable => 1,
+            plural => 'fortune cookies', stackable => 1, material => 'veggy',
         },
         'candy bar' => {
             price => 10, weight => 2, nutrition => 100, time => 1,
-            plural => 'candy bars', stackable => 1,
+            plural => 'candy bars', stackable => 1, material => 'veggy',
         },
         'cream pie' => {
             price => 10, weight => 10, nutrition => 100, time => 1,
-            plural => 'cream pies', stackable => 1,
+            plural => 'cream pies', stackable => 1, material => 'veggy',
         },
         'lump of royal jelly' => {
             price => 15, weight => 2, nutrition => 200, time => 1,
             plural => 'lumps of royal jelly', stackable => 1,
+            material => 'veggy',
         },
         'pancake' => {
             price => 15, weight => 2, nutrition => 200, time => 2,
-            plural => 'pancakes', stackable => 1,
+            plural => 'pancakes', stackable => 1, material => 'veggy',
         },
         'C-ration' => {
             price => 20, weight => 10, nutrition => 300, time => 1,
-            plural => 'C-rations', stackable => 1,
+            plural => 'C-rations', stackable => 1, material => 'veggy',
         },
         'K-ration' => {
             price => 25, weight => 10, nutrition => 400, time => 1,
-            plural => 'K-rations', stackable => 1,
+            plural => 'K-rations', stackable => 1, material => 'veggy',
         },
         'cram ration' => {
             price => 35, weight => 15, nutrition => 600, time => 3,
-            plural => 'cram rations', stackable => 1,
+            plural => 'cram rations', stackable => 1, material => 'veggy',
         },
         'food ration' => {
             price => 45, weight => 20, nutrition => 800, time => 5,
-            plural => 'food rations', stackable => 1,
+            plural => 'food rations', stackable => 1, material => 'veggy',
         },
         'lembas wafer' => {
             price => 45, weight => 5, nutrition => 800, time => 2,
-            plural => 'lembas wafers', stackable => 1,
+            plural => 'lembas wafers', stackable => 1, material => 'veggy',
         },
         'empty tin' => {
             nutrition  => 0,
@@ -120,6 +122,7 @@ sub _list {
             appearance => 'tin',
             weight     => 10,
             stackable  => 1,
+            material   => 'metal',
         },
         'tin of spinach' => {
             nutrition  => 800,
@@ -127,6 +130,7 @@ sub _list {
             appearance => 'tin',
             weight     => 10,
             stackable  => 1,
+            material   => 'metal',
         },
     };
 
@@ -140,7 +144,8 @@ sub _list {
             nutrition   => 0,
         },
         'Arch Priest' => {
-            unique    => 1,
+            unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -166,6 +171,7 @@ sub _list {
         },
         'Chromatic Dragon' => {
             unique      => 1,
+            improper    => 1,
             weight      => 4500,
             nutrition   => 1700,
             cold        => '17%',
@@ -184,12 +190,14 @@ sub _list {
         },
         'Cyclops' => {
             unique      => 1,
+            improper    => 1,
             weight      => 1900,
             nutrition   => 700,
             strength    => '100%',
         },
         'Dark One' => {
             unique      => 1,
+            improper    => 1,
             weight      => 1450,
             nutrition   => 0,
         },
@@ -228,6 +236,7 @@ sub _list {
         },
         'Grand Master' => {
             unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -308,6 +317,7 @@ sub _list {
         },
         'Master Assassin' => {
             unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -321,6 +331,7 @@ sub _list {
         },
         'Master of Thieves' => {
             unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -335,6 +346,7 @@ sub _list {
         },
         'Minion of Huhetotl' => {
             unique      => 1,
+            improper    => 1,
             weight      => 1450,
             nutrition   => 0,
         },
@@ -359,6 +371,7 @@ sub _list {
         },
         'Norn' => {
             unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -369,6 +382,7 @@ sub _list {
         },
         'Oracle' => {
             unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -431,6 +445,7 @@ sub _list {
         },
         'Wizard of Yendor' => {
             unique      => 1,
+            improper    => 1,
             cannibal    => "Hum",
             weight      => 1450,
             nutrition   => 400,
@@ -2069,15 +2084,23 @@ sub _list {
     # Collect monster corpses, tins, and eggs
     for my $name (keys %monsterlist) {
         my $stats = $monsterlist{$name};
-        $food->{"$name corpse"}          = $stats;
-        $food->{"$name corpse"}{corpse}  = 1;
-        $food->{"$name corpse"}{subtype} = 'corpse';
-        $food->{"$name corpse"}{monster} = $name;
-        $food->{"$name corpse"}{plural}  = "$name corpses";
-        $food->{"$name corpse"}{stackable} = 1;
-        $food->{"$name corpse"}{permanent} ||= 0;
+        my $adjname = $name;
 
-        my $tin_name = $name;
+        if ($stats->{unique}) {
+            $adjname .= ($adjname =~ /s$/ ? "'" : "'s");
+            $adjname = "the " . $adjname if $stats->{improper};
+        }
+
+        $food->{"$adjname corpse"}          = $stats;
+        $food->{"$adjname corpse"}{corpse}  = 1;
+        $food->{"$adjname corpse"}{material}= 'flesh';
+        $food->{"$adjname corpse"}{subtype} = 'corpse';
+        $food->{"$adjname corpse"}{monster} = $name;
+        $food->{"$adjname corpse"}{plural}  = "$adjname corpses";
+        $food->{"$adjname corpse"}{stackable} = 1;
+        $food->{"$adjname corpse"}{permanent} ||= 0;
+
+        my $tin_name = $adjname;
         $tin_name .= " meat"
             unless $stats->{vegetarian};
         $food->{"tin of $tin_name"} = {
@@ -2085,6 +2108,7 @@ sub _list {
             plural     => "tins of $tin_name",
             weight     => 10,
             stackable  => 1,
+            material   => 'metal',
         };
 
         if ($stats->{has_egg}) {
@@ -2097,6 +2121,7 @@ sub _list {
                 appearance => "egg",
                 plural     => "$name eggs",
                 stackable  => 1,
+                material   => 'flesh',
             };
         }
     }
