@@ -1,6 +1,5 @@
-#!/usr/bin/env perl
 package NetHack::Item::Spoiler::Other;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use strict;
 use warnings;
@@ -16,6 +15,7 @@ sub _list {
             glyph  => '$',
             plural => 'gold pieces',
             stackable  => 1,
+            material => 'gold',
         },
         'boulder' => {
             price     => 0,
@@ -25,6 +25,7 @@ sub _list {
             ldam      => 'd20',
             nutrition => 2000,
             plural    => 'boulders',
+            material  => 'mineral',
         },
         'statue' => {
             price     => 0,
@@ -34,6 +35,7 @@ sub _list {
             ldam      => 'd20',
             nutrition => 2500,
             plural    => 'statues',
+            material  => 'mineral',
         },
         'heavy iron ball' => {
             price     => 10,
@@ -43,6 +45,7 @@ sub _list {
             ldam      => 'd25',
             nutrition => 480,
             plural    => 'heavy iron balls',
+            material  => 'iron',
         },
         'iron chain' => {
             price     => 0,
@@ -52,6 +55,7 @@ sub _list {
             ldam      => 'd4+1',
             nutrition => 120,
             plural    => 'iron chains',
+            material  => 'iron',
         },
         'acid venom' => {
             price  => 0,
@@ -61,6 +65,7 @@ sub _list {
             ldam   => '2d6',
             plural => 'acid venoms',
             stackable  => 1,
+            material   => 'liquid',
         },
         'blinding venom' => {
             price  => 0,
@@ -68,6 +73,7 @@ sub _list {
             glyph  => '.',
             plural => 'blinding venoms',
             stackable  => 1,
+            material   => 'liquid',
         },
     };
 
