@@ -1,6 +1,5 @@
-#!/usr/bin/env perl
 package NetHack::Item::Spoiler::Tool;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use strict;
 use warnings;
@@ -18,6 +17,8 @@ sub _list {
             fullname => 'The Bell of Opening',
             appearance => 'silver bell',
             subtype => 'instrument',
+            material => 'silver',
+            tonal => 0,
         },
         'Candelabrum of Invocation' => {
             artifact => 1,
@@ -27,6 +28,7 @@ sub _list {
             fullname => 'The Candelabrum of Invocation',
             appearance => 'candelabrum',
             subtype => 'candelabrum',
+            material => 'gold',
         },
 
         'Eyes of the Overworld' => {
@@ -37,6 +39,7 @@ sub _list {
             charge => 0,
             fullname => 'The Eyes of the Overworld',
             subtype => 'accessory',
+            material => 'glass',
         },
         'Magic Mirror of Merlin' => {
             artifact => 1,
@@ -45,6 +48,7 @@ sub _list {
             weight => 13,
             charge => 0,
             fullname => 'The Magic Mirror of Merlin',
+            material => 'glass',
         },
         'Master Key of Thievery' => {
             artifact => 1,
@@ -54,6 +58,7 @@ sub _list {
             charge => 0,
             fullname => 'The Master Key of Thievery',
             subtype => 'key',
+            material => 'iron',
         },
         'Orb of Detection' => {
             artifact => 1,
@@ -62,6 +67,7 @@ sub _list {
             weight => 150,
             charge => 5,
             fullname => 'The Orb of Detection',
+            material => 'glass',
         },
         'Orb of Fate' => {
             artifact => 1,
@@ -70,6 +76,7 @@ sub _list {
             weight => 150,
             charge => 5,
             fullname => 'The Orb of Fate',
+            material => 'glass',
         },
         'Platinum Yendorian Express Card' => {
             artifact => 1,
@@ -79,6 +86,7 @@ sub _list {
             charge => 0,
             fullname => 'The Platinum Yendorian Express Card',
             subtype => 'key',
+            material => 'plastic',
         },
 
         'large box' => {
@@ -86,18 +94,21 @@ sub _list {
             weight => 350,
             charge => 0,
             subtype => 'container',
+            material => 'wood',
         },
         'chest' => {
             price => 16,
             weight => 600,
             charge => 0,
             subtype => 'container',
+            material => 'wood',
         },
         'ice box' => {
             price => 42,
             weight => 900,
             charge => 0,
             subtype => 'container',
+            material => 'plastic',
         },
         'sack' => {
             price => 2,
@@ -105,6 +116,7 @@ sub _list {
             charge => 0,
             appearance => 'bag',
             subtype => 'container',
+            material => 'cloth',
         },
         'bag of holding' => {
             price => 100,
@@ -112,12 +124,14 @@ sub _list {
             charge => 0,
             appearance => 'bag',
             subtype => 'container',
+            material => 'cloth',
         },
         'bag of tricks' => {
             price => 100,
             weight => 15,
             charge => 20,
             appearance => 'bag',
+            material => 'cloth',
             # NOT A CONTAINER!!
         },
         'oilskin sack' => {
@@ -126,6 +140,7 @@ sub _list {
             charge => 0,
             appearance => 'bag',
             subtype => 'container',
+            material => 'cloth',
         },
 
         'credit card' => {
@@ -133,12 +148,14 @@ sub _list {
             weight => 1,
             charge => 0,
             subtype => 'key',
+            material => 'plastic',
         },
         'lock pick' => {
             price => 20,
             weight => 4,
             charge => 0,
             subtype => 'key',
+            material => 'iron',
         },
         'skeleton key' => {
             price => 10,
@@ -146,6 +163,7 @@ sub _list {
             charge => 0,
             appearance => 'key',
             subtype => 'key',
+            material => 'iron',
         },
 
         'tallow candle' => {
@@ -156,6 +174,7 @@ sub _list {
             plural => 'tallow candles',
             subtype => 'light',
             stackable => 1,
+            material => 'wax',
         },
         'wax candle' => {
             price => 20,
@@ -165,12 +184,14 @@ sub _list {
             plural => 'wax candles',
             subtype => 'light',
             stackable => 1,
+            material => 'wax',
         },
         'brass lantern' => {
             price => 12,
             weight => 30,
             charge => 1499,
             subtype => 'light',
+            material => 'copper',
         },
         'oil lamp' => {
             price => 10,
@@ -178,6 +199,7 @@ sub _list {
             charge => 1499,
             appearance => 'lamp',
             subtype => 'light',
+            material => 'copper',
         },
         'magic lamp' => {
             price => 50,
@@ -185,6 +207,7 @@ sub _list {
             charge => 0,
             appearance => 'lamp',
             subtype => 'light',
+            material => 'copper',
         },
 
         'tin whistle' => {
@@ -194,6 +217,7 @@ sub _list {
             appearance => 'whistle',
             subtype => 'instrument',
             tonal => 0,
+            material => 'metal',
         },
         'magic whistle' => {
             price => 10,
@@ -202,6 +226,7 @@ sub _list {
             appearance => 'whistle',
             subtype => 'instrument',
             tonal => 0,
+            material => 'metal',
         },
         'bugle' => {
             price => 15,
@@ -209,6 +234,7 @@ sub _list {
             charge => 0,
             subtype => 'instrument',
             tonal => 1,
+            material => 'copper',
         },
         'wooden flute' => {
             price => 12,
@@ -217,6 +243,7 @@ sub _list {
             appearance => 'flute',
             subtype => 'instrument',
             tonal => 1,
+            material => 'wood',
         },
         'magic flute' => {
             price => 36,
@@ -225,6 +252,7 @@ sub _list {
             appearance => 'flute',
             subtype => 'instrument',
             tonal => 1,
+            material => 'wood',
         },
         'tooled horn' => {
             price => 15,
@@ -233,6 +261,7 @@ sub _list {
             appearance => 'horn',
             subtype => 'instrument',
             tonal => 1,
+            material => 'bone',
         },
         'frost horn' => {
             price => 50,
@@ -241,6 +270,7 @@ sub _list {
             appearance => 'horn',
             subtype => 'instrument',
             tonal => 1,
+            material => 'bone',
         },
         'fire horn' => {
             price => 50,
@@ -249,6 +279,7 @@ sub _list {
             appearance => 'horn',
             subtype => 'instrument',
             tonal => 1,
+            material => 'bone',
         },
         'horn of plenty' => {
             price => 50,
@@ -257,6 +288,7 @@ sub _list {
             appearance => 'horn',
             subtype => 'instrument',
             tonal => 0,
+            material => 'bone',
         },
         'leather drum' => {
             price => 25,
@@ -265,6 +297,7 @@ sub _list {
             appearance => 'drum',
             subtype => 'instrument',
             tonal => 0,
+            material => 'leather',
         },
         'drum of earthquake' => {
             price => 25,
@@ -273,6 +306,7 @@ sub _list {
             appearance => 'drum',
             subtype => 'instrument',
             tonal => 0,
+            material => 'leather',
         },
         'wooden harp' => {
             price => 50,
@@ -281,6 +315,7 @@ sub _list {
             appearance => 'harp',
             subtype => 'instrument',
             tonal => 1,
+            material => 'wood',
         },
         'magic harp' => {
             price => 50,
@@ -289,6 +324,7 @@ sub _list {
             appearance => 'harp',
             subtype => 'instrument',
             tonal => 1,
+            material => 'wood',
         },
         'bell' => {
             price => 50,
@@ -296,6 +332,7 @@ sub _list {
             charge => 0,
             subtype => 'instrument',
             tonal => 0,
+            material => 'copper',
         },
 
         'beartrap' => {
@@ -303,6 +340,7 @@ sub _list {
             weight => 200,
             charge => 0,
             subtype => 'trap',
+            material => 'iron',
         },
         'land mine' => {
             price => 180,
@@ -310,6 +348,7 @@ sub _list {
             charge => 0,
             appearance => 'land mine',
             subtype => 'trap',
+            material => 'iron',
         },
 
         'pick-axe' => {
@@ -351,77 +390,91 @@ sub _list {
             price => 200,
             weight => 12,
             charge => 99,
+            material => 'plastic',
         },
         'mirror' => {
             price => 10,
             weight => 13,
             charge => 0,
             appearance => 'looking glass',
+            material => 'glass',
         },
         'crystal ball' => {
             price => 60,
             weight => 150,
             charge => 5,
             appearance => 'glass orb',
+            material => 'glass',
         },
         'lenses' => {
             price => 80,
             weight => 3,
             charge => 0,
             subtype => 'accessory',
+            material => 'glass',
         },
         'blindfold' => {
             price => 20,
             weight => 2,
             charge => 0,
             subtype => 'accessory',
+            material => 'cloth',
         },
         'towel' => {
             price => 50,
             weight => 2,
             charge => 0,
             subtype => 'accessory',
+            material => 'cloth',
         },
         'saddle' => {
             price => 150,
             weight => 200,
             charge => 0,
+            material => 'leather',
         },
         'leash' => {
             price => 20,
             weight => 12,
             charge => 0,
+            material => 'leather',
         },
         'stethoscope' => {
             price => 75,
             weight => 4,
             charge => 0,
+            material => 'iron',
         },
         'tinning kit' => {
             price => 30,
             weight => 100,
             charge => 99,
+            material => 'iron',
         },
         'tin opener' => {
             price => 30,
             weight => 4,
             charge => 0,
+            material => 'iron',
         },
         'can of grease' => {
             price => 20,
             weight => 15,
             charge => 25,
+            material => 'iron',
         },
         'figurine' => {
             price => 80,
             weight => 50,
             charge => 0,
             subtype => 'figurine',
+            material => 'mineral',
         },
         'magic marker' => {
             price => 50,
             weight => 2,
             charge => 99,
+            material => 'plastic',
         },
     };
 
