@@ -1,12 +1,13 @@
-#!/usr/bin/env perl
 package NetHack::Item::Tool::Instrument;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Moose;
 extends 'NetHack::Item::Tool';
 
 use constant subtype => 'instrument';
 
+__PACKAGE__->meta->install_spoilers('tonal');
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
